@@ -3,9 +3,7 @@
 import argparse
 import yaml
 import os
-import ybase
-from yaml_worker import YamlActionsWorker
-
+from .ybase import YBase
 import sys
 
 
@@ -24,7 +22,7 @@ def main():
 
     args = parser.parse_args()
 
-    # base = YBase(args.cfg_path, args.action)
+    base = YBase(args.cfg_path, args.action)
     # base.do_actions()
 
 
